==> deepin-kwin-debug-6.0.8-3-x86_64.pkg.tar.zst: usr/src/debug/deepin-kwin/deepin-kwin/src/effects/startupfeedback/startupfeedback_autogen/EWIEGA46WW/qrc_startupfeedback.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // blinking-startup_core.frag
  0x0,0x0,0x0,0xfa,
  0x23,
  0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x20,0x31,0x34,0x30,0xa,0x75,0x6e,0x69,0x66,
  0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,0x20,0x73,0x61,
  0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x76,
  0x65,0x63,0x34,0x20,0x67,0x65,0x6f,0x6d,0x65,0x74,0x72,0x79,0x43,0x6f,0x6c,0x6f,
  0x72,0x3b,0xa,0xa,0x69,0x6e,0x20,0x76,0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,
  0x6f,0x6f,0x72,0x64,0x30,0x3b,0xa,0xa,0x6f,0x75,0x74,0x20,0x76,0x65,0x63,0x34,
  0x20,0x66,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x3b,0xa,0xa,0x76,0x6f,0x69,
  0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,
  0x65,0x63,0x34,0x20,0x74,0x65,0x78,0x20,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,
  0x65,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x29,0x3b,0xa,0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x74,
  0x65,0x78,0x2e,0x61,0x20,0x21,0x3d,0x20,0x31,0x2e,0x30,0x29,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x74,0x65,0x78,0x20,0x3d,0x20,0x67,0x65,0x6f,
  0x6d,0x65,0x74,0x72,0x79,0x43,0x6f,0x6c,0x6f,0x72,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x7d,0xa,0x20,0x20,0x20,0x20,0x66,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,
  0x3d,0x20,0x74,0x65,0x78,0x3b,0xa,0x7d,0xa,
    // blinking-startup.frag
  0x0,0x0,0x0,0xe2,
  0x75,
  0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,
  0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,
  0x6d,0x20,0x76,0x65,0x63,0x34,0x20,0x67,0x65,0x6f,0x6d,0x65,0x74,0x72,0x79,0x43,
  0x6f,0x6c,0x6f,0x72,0x3b,0xa,0xa,0x76,0x61,0x72,0x79,0x69,0x6e,0x67,0x20,0x76,
  0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x3b,0xa,0xa,
  0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x29,0xa,0x7b,0xa,0x20,0x20,
  0x20,0x20,0x76,0x65,0x63,0x34,0x20,0x74,0x65,0x78,0x20,0x3d,0x20,0x74,0x65,0x78,
  0x74,0x75,0x72,0x65,0x32,0x44,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,
  0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x29,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x69,0x66,0x20,0x28,0x74,0x65,0x78,0x2e,0x61,0x20,0x21,0x3d,0x20,0x31,0x2e,0x30,
  0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x74,0x65,0x78,0x20,
  0x3d,0x20,0x67,0x65,0x6f,0x6d,0x65,0x74,0x72,0x79,0x43,0x6f,0x6c,0x6f,0x72,0x3b,
  0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,0x5f,0x46,0x72,
  0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,0x3d,0x20,0x74,0x65,0x78,0x3b,0xa,0x7d,
  0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // effects
  0x0,0x7,
  0xb,0xcc,0xba,0x73,
  0x0,0x65,
  0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // startupfeedback
  0x0,0xf,
  0xa,0x8c,0xe0,0xbb,
  0x0,0x73,
  0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x70,0x0,0x66,0x0,0x65,0x0,0x65,0x0,0x64,0x0,0x62,0x0,0x61,0x0,0x63,0x0,0x6b,
    // shaders
  0x0,0x7,
  0x9,0xe7,0xac,0x73,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x73,
    // blinking-startup_core.frag
  0x0,0x1a,
  0xf,0xa,0x65,0x57,
  0x0,0x62,
  0x0,0x6c,0x0,0x69,0x0,0x6e,0x0,0x6b,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2d,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x70,0x0,0x5f,
  0x0,0x63,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
    // blinking-startup.frag
  0x0,0x15,
  0x4,0x24,0x97,0x17,
  0x0,0x62,
  0x0,0x6c,0x0,0x69,0x0,0x6e,0x0,0x6b,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2d,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x70,0x0,0x2e,
  0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xcf,0x2b,0xbc,0x30,
  // :/effects
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xcf,0x2b,0xbc,0x30,
  // :/effects/startupfeedback
  0x0,0x0,0x0,0x14,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xcf,0x2b,0xbc,0x30,
  // :/effects/startupfeedback/shaders
  0x0,0x0,0x0,0x38,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xcf,0x2b,0xbc,0x30,
  // :/effects/startupfeedback/shaders/blinking-startup.frag
  0x0,0x0,0x0,0x86,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xfe,
0x0,0x0,0x1,0x99,0xcf,0x2b,0xbc,0x30,
  // :/effects/startupfeedback/shaders/blinking-startup_core.frag
  0x0,0x0,0x0,0x4c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xcf,0x2b,0xbc,0x30,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_startupfeedback)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_startupfeedback)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_startupfeedback)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_startupfeedback)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_startupfeedback)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_startupfeedback)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-kwin-debug-6.0.8-4-x86_64.pkg.tar.zst: usr/src/debug/deepin-kwin/deepin-kwin/src/effects/startupfeedback/startupfeedback_autogen/EWIEGA46WW/qrc_startupfeedback.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // blinking-startup_core.frag
  0x0,0x0,0x0,0xfa,
  0x23,
  0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x20,0x31,0x34,0x30,0xa,0x75,0x6e,0x69,0x66,
  0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,0x20,0x73,0x61,
  0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x76,
  0x65,0x63,0x34,0x20,0x67,0x65,0x6f,0x6d,0x65,0x74,0x72,0x79,0x43,0x6f,0x6c,0x6f,
  0x72,0x3b,0xa,0xa,0x69,0x6e,0x20,0x76,0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,
  0x6f,0x6f,0x72,0x64,0x30,0x3b,0xa,0xa,0x6f,0x75,0x74,0x20,0x76,0x65,0x63,0x34,
  0x20,0x66,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x3b,0xa,0xa,0x76,0x6f,0x69,
  0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x29,0xa,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,
  0x65,0x63,0x34,0x20,0x74,0x65,0x78,0x20,0x3d,0x20,0x74,0x65,0x78,0x74,0x75,0x72,
  0x65,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,0x74,0x65,0x78,0x63,0x6f,
  0x6f,0x72,0x64,0x30,0x29,0x3b,0xa,0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x74,
  0x65,0x78,0x2e,0x61,0x20,0x21,0x3d,0x20,0x31,0x2e,0x30,0x29,0x20,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x74,0x65,0x78,0x20,0x3d,0x20,0x67,0x65,0x6f,
  0x6d,0x65,0x74,0x72,0x79,0x43,0x6f,0x6c,0x6f,0x72,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x7d,0xa,0x20,0x20,0x20,0x20,0x66,0x72,0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,
  0x3d,0x20,0x74,0x65,0x78,0x3b,0xa,0x7d,0xa,
    // blinking-startup.frag
  0x0,0x0,0x0,0xe2,
  0x75,
  0x6e,0x69,0x66,0x6f,0x72,0x6d,0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x32,0x44,
  0x20,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x3b,0xa,0x75,0x6e,0x69,0x66,0x6f,0x72,
  0x6d,0x20,0x76,0x65,0x63,0x34,0x20,0x67,0x65,0x6f,0x6d,0x65,0x74,0x72,0x79,0x43,
  0x6f,0x6c,0x6f,0x72,0x3b,0xa,0xa,0x76,0x61,0x72,0x79,0x69,0x6e,0x67,0x20,0x76,
  0x65,0x63,0x32,0x20,0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x3b,0xa,0xa,
  0x76,0x6f,0x69,0x64,0x20,0x6d,0x61,0x69,0x6e,0x28,0x29,0xa,0x7b,0xa,0x20,0x20,
  0x20,0x20,0x76,0x65,0x63,0x34,0x20,0x74,0x65,0x78,0x20,0x3d,0x20,0x74,0x65,0x78,
  0x74,0x75,0x72,0x65,0x32,0x44,0x28,0x73,0x61,0x6d,0x70,0x6c,0x65,0x72,0x2c,0x20,
  0x74,0x65,0x78,0x63,0x6f,0x6f,0x72,0x64,0x30,0x29,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x69,0x66,0x20,0x28,0x74,0x65,0x78,0x2e,0x61,0x20,0x21,0x3d,0x20,0x31,0x2e,0x30,
  0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x74,0x65,0x78,0x20,
  0x3d,0x20,0x67,0x65,0x6f,0x6d,0x65,0x74,0x72,0x79,0x43,0x6f,0x6c,0x6f,0x72,0x3b,
  0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x67,0x6c,0x5f,0x46,0x72,
  0x61,0x67,0x43,0x6f,0x6c,0x6f,0x72,0x20,0x3d,0x20,0x74,0x65,0x78,0x3b,0xa,0x7d,
  0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // effects
  0x0,0x7,
  0xb,0xcc,0xba,0x73,
  0x0,0x65,
  0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // startupfeedback
  0x0,0xf,
  0xa,0x8c,0xe0,0xbb,
  0x0,0x73,
  0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x70,0x0,0x66,0x0,0x65,0x0,0x65,0x0,0x64,0x0,0x62,0x0,0x61,0x0,0x63,0x0,0x6b,
    // shaders
  0x0,0x7,
  0x9,0xe7,0xac,0x73,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,0x73,
    // blinking-startup_core.frag
  0x0,0x1a,
  0xf,0xa,0x65,0x57,
  0x0,0x62,
  0x0,0x6c,0x0,0x69,0x0,0x6e,0x0,0x6b,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2d,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x70,0x0,0x5f,
  0x0,0x63,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
    // blinking-startup.frag
  0x0,0x15,
  0x4,0x24,0x97,0x17,
  0x0,0x62,
  0x0,0x6c,0x0,0x69,0x0,0x6e,0x0,0x6b,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2d,0x0,0x73,0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x70,0x0,0x2e,
  0x0,0x66,0x0,0x72,0x0,0x61,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0xbf,0x4f,0xa4,0x38,
  // :/effects
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0xbf,0x4f,0xa4,0x38,
  // :/effects/startupfeedback
  0x0,0x0,0x0,0x14,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0xbf,0x4f,0xa4,0x38,
  // :/effects/startupfeedback/shaders
  0x0,0x0,0x0,0x38,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0xbf,0x4f,0xa4,0x38,
  // :/effects/startupfeedback/shaders/blinking-startup.frag
  0x0,0x0,0x0,0x86,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xfe,
0x0,0x0,0x1,0x9a,0xbf,0x4f,0xa4,0x38,
  // :/effects/startupfeedback/shaders/blinking-startup_core.frag
  0x0,0x0,0x0,0x4c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0xbf,0x4f,0xa4,0x38,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_startupfeedback)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_startupfeedback)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_startupfeedback)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_startupfeedback)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_startupfeedback)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_startupfeedback)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
